"use strict";

//#region index.mjs
function colorfulPlugin(md, options) {
	const pattern = /::(colorful(_(#(?:[0-9a-fA-F]{8}|[0-9a-fA-F]{6}|[0-9a-fA-F]{3})|(?:[a-zA-Z]+))?){0,2})\s+(.*?)::/i;
	const COLORFUL = "colorful";
	const config = Object.assign({
		color: null,
		bgColor: null,
		skipWhenNoStyle: false
	}, options || {});
	this.set = function(newOpt = {}) {
		if (typeof newOpt !== "object") return;
		Object.assign(config, newOpt);
	};
	function colorful(state, silent) {
		const pos = state.pos;
		const str = state.src.slice(pos);
		if (!str.startsWith("::colorful")) return false;
		const match = pattern.exec(str);
		if (!match) return false;
		const { color, bgColor, skipWhenNoStyle } = config;
		const colors = match[1].split("_");
		const styleBgColor = colors[1] || bgColor;
		const styleColor = colors[2] || color;
		let style = "";
		styleBgColor && (style += `background-color: ${styleBgColor};`);
		styleColor && (style += `color: ${styleColor};`);
		const content = match[match.length - 1];
		const inlineTokens = md.parseInline(content, state.env);
		if (!style && skipWhenNoStyle) {
			state.src = state.src.replace(match[0], content);
			return false;
		}
		const token = state.push(COLORFUL, "span", 1);
		token.attrPush(["class", "colorful"]);
		style && token.attrPush(["style", style]);
		token.children = inlineTokens;
		state.pos += match[0].length;
		return true;
	}
	if (md.inline.ruler.__find__(COLORFUL) === -1) md.inline.ruler.push(COLORFUL, colorful);
else md.inline.ruler.at(COLORFUL, colorful);
	md.renderer.rules[COLORFUL] = function(tokens, idx, options$1, env, self) {
		const token = tokens[idx];
		const span_s = self.renderToken([token], 0, options$1);
		const span_e = "</span>";
		const childrenContent = self.render(token.children, options$1, env);
		return span_s + childrenContent + span_e;
	};
	return md;
}
var markdown_it_colorful_default = colorfulPlugin;

//#endregion
module.exports = markdown_it_colorful_default;